import { useState, useEffect, useMemo, useCallback } from 'react';
import { AgGridReact } from 'ag-grid-react';
import { api, useStaff } from "@nice/client";
import 'ag-grid-community/styles/ag-grid.css';
import 'ag-grid-community/styles/ag-theme-alpine.css';
import { SetFilterModule } from 'ag-grid-enterprise';
import { Button, message } from 'antd';

export default function StaffMessage() {
    const [rowData, setRowData] = useState<any[]>([]);
    const [columnDefs, setColumnDefs] = useState<any[]>([]);
    const [selectedRows, setSelectedRows] = useState<any[]>([]);
    const { useCustomFields, softDeleteByIds } = useStaff();
    const fields = useCustomFields();

    // 获取数据
    const { data: staffData } = api.staff.findMany.useQuery({
        where: {
            deletedAt: null
        },
        include: {
            fieldValues: {
                include: {
                    // 添加这两个关联字段
                    staff: { select: { id: true } },  // 关联员工ID
                    field: { select: { id: true } }   // 关联字段ID
                }
            },
            department: true
        }
    } as any);

    const actionColumns = [{
        field:"action",
        width: 50,
        checkboxSelection: true,
        headerCheckboxSelection: true,
        pinned: 'left'
    }]

    // 新增编辑处理函数
    const handleEdit = useCallback(async () => {
        if (selectedRows.length === 0) return;
        if (selectedRows.length > 1) {
            message.error('只能选择一个员工进行编辑');
            return;
        }
        console.log(selectedRows[0]);
    }, [selectedRows]);

    // 新增删除处理函数
    const handleDelete = useCallback(async () => {
        if (selectedRows.length === 0) return;
        try {
            await softDeleteByIds.mutateAsync({
                ids: selectedRows?.map(row => row.id)
            });
            message.success('删除成功');
        } catch (error) {
            message.error('删除失败');
        }
        // 重新获取数据或本地过滤已删除项
    }, [selectedRows]);

    // 缓存基础列定义
    const baseColumns = useMemo(() => [
        {
            field: 'showname',
            headerName: '姓名',
            filter: 'agSetColumnFilter',
            pinned: 'left'
        },
        {
            field: 'deptId',
            headerName: '所属部门',
            valueGetter: params => params.data.department?.name,
            filter: 'agSetColumnFilter'
        }
    ], []);

    // 缓存动态列定义
    const dynamicColumns = useMemo(() =>
        (fields.data || [] as any).map(field => ({
            field: field.name,
            headerName: field.label || field.name,
            filter: 'agSetColumnFilter',
            valueGetter: params => {
                // 从 fieldValues 对象中获取值
                return params.data.fieldValues?.find(
                    (fv: any) => fv.fieldId === field.id
                )?.value;
            }
        })),
        [fields.data]
    );

    // 合并列定义
    useEffect(() => {
        setColumnDefs([...actionColumns, ...baseColumns, ...dynamicColumns]);
    }, [baseColumns, dynamicColumns]);

    // 更新行数据
    useEffect(() => {
        staffData && setRowData(staffData);
    }, [staffData]);

    return (

        <>
            <Button className='mr-2' danger onClick={handleDelete} style={{ marginBottom: '10px' }}>批量删除</Button>
            <Button type="primary" onClick={handleEdit} style={{ marginBottom: '10px' }}>编辑</Button>
            <div className="ag-theme-alpine" style={{ height: 500, width: '100%', padding: '20px' }}>
                <h1 className="text-2xl mb-4">人员总览</h1>
                <AgGridReact
                    modules={[SetFilterModule]}
                    rowData={rowData}
                    columnDefs={columnDefs}
                    pagination={true}
                    paginationPageSize={10}
                    onSelectionChanged={e => setSelectedRows(e.api.getSelectedRows())}
                    rowSelection="multiple"
                />
            </div>
            <Button onClick={() => {
                console.log('字段配置:', fields.data);
                console.log('员工数据:', staffData);
            }}>调试数据</Button>
        </>
    );
}